@@ -423,6 +423,20 @@ static bool getTerminalVersionScreen(FFstrbuf* exe, FFstrbuf* version)
     return version->length > 0;
 }
 
+static bool getTerminalVersionTmux(FFstrbuf* exe, FFstrbuf* version)
+{
+    if (ffProcessAppendStdOut(version, (char* const[]) {
+        exe->chars,
+        "-V",
+        NULL
+    }) != NULL)
+        return false;
+
+    // tmux 3.4
+    ffStrbufSubstrAfterFirstC(version, ' ');
+    return version->length > 0;
+}
+
 #ifdef _WIN32
 
 static bool getTerminalVersionWindowsTerminal(FFstrbuf* exe, FFstrbuf* version)
@@ -548,7 +562,13 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
         {
             if(ffStrbufStartsWithIgnCaseS(processName, termProgram) || // processName ends with `.exe` on Windows
                 (ffStrEquals(termProgram, "vscode") && ffStrbufStartsWithIgnCaseS(processName, "code")) ||
-                (ffStrEquals(termProgram, "iTerm.app") && ffStrbufStartsWithIgnCaseS(processName, "iTermServer-"))
+
+                #ifdef __APPLE__
+                (ffStrEquals(termProgram, "iTerm.app") && ffStrbufStartsWithIgnCaseS(processName, "iTermServer-")) ||
+                #elif defined(__linux__)
+                (ffStrEquals(termProgram, "WarpTerminal") && ffStrbufEqualS(processName, "warp")) ||
+                #endif
+                false
             ) {
                 ffStrbufSetS(version, termProgramVersion);
                 return true;
@@ -572,6 +592,9 @@ bool fftsGetTerminalVersion(FFstrbuf* processName, FF_MAYBE_UNUSED FFstrbuf* exe
         }
     }
 
+    if(ffStrbufStartsWithIgnCaseS(processName, "tmux"))
+        return getTerminalVersionTmux(exe, version);
+
     #ifdef _WIN32
 
     return getFileVersion(exe->chars, version);
